@@ -31,11 +31,8 @@ import shutil
 import unittest
 
 import httpretty
-import pkg_resources
 import requests
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.errors import BackendError, ParseError
 from perceval.utils import DEFAULT_DATETIME
