@@ -30,11 +30,8 @@ import tempfile
 import unittest
 
 import httpretty
-import pkg_resources
 import requests
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from grimoirelab_toolkit.datetime import datetime_utcnow
 
 from perceval.archive import Archive
