@@ -25,7 +25,6 @@
 import datetime
 import httpretty
 import os
-import pkg_resources
 import requests
 import shutil
 import tempfile
@@ -33,8 +32,6 @@ import unittest
 import unittest.mock
 import zipfile
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.errors import BackendError
 from perceval.utils import DEFAULT_DATETIME
